@@ -1,16 +1,16 @@
 from collections import namedtuple
 from tempfile import NamedTemporaryFile
 import matplotlib.pyplot as plt
-from typing import List, Any, Union
 import numpy as np
 import tqdm
-import axelrod as axl
 
+import axelrod as axl
 from axelrod import on_windows, Player
 from axelrod.strategy_transformers import JossAnnTransformer, DualTransformer
 from axelrod.interaction_utils import (
     compute_final_score_per_turn, read_interactions_from_file)
 
+from typing import List, Any, Union
 
 Point = namedtuple('Point', 'x y')
 
@@ -310,11 +310,9 @@ class AshlockFingerprint(object):
             step, progress_bar=progress_bar)
 
         self.step = step
-        self.spatial_tournament = axl.SpatialTournament(
-            tourn_players,
-            turns=turns,
-            repetitions=repetitions,
-            edges=edges)
+        self.spatial_tournament = axl.Tournament(tourn_players, turns=turns,
+                                                 repetitions=repetitions,
+                                                 edges=edges)
         self.spatial_tournament.play(build_results=False,
                                      filename=filename,
                                      processes=processes,
@@ -329,14 +327,14 @@ class AshlockFingerprint(object):
         self.data = generate_data(self.interactions, self.points, edges)
         return self.data
 
-    def plot(self, col_map: str = 'seismic', interpolation: str = 'none',
+    def plot(self, cmap: str = 'seismic', interpolation: str = 'none',
              title: str = None, colorbar: bool = True,
              labels: bool = True) -> plt.Figure:
         """Plot the results of the spatial tournament.
 
         Parameters
         ----------
-        col_map : str, optional
+        cmap : str, optional
             A matplotlib colour map, full list can be found at
             http://matplotlib.org/examples/color/colormaps_reference.html
         interpolation : str, optional
@@ -358,7 +356,7 @@ class AshlockFingerprint(object):
         plotting_data = reshape_data(self.data, self.points, size)
         fig, ax = plt.subplots()
         cax = ax.imshow(
-            plotting_data, cmap=col_map, interpolation=interpolation)
+            plotting_data, cmap=cmap, interpolation=interpolation)
 
         if colorbar:
             max_score = max(self.data.values())
