@@ -1,7 +1,7 @@
-from .actions import Action, Actions
+from .action import Action
 from typing import Tuple, Union
 
-C, D = Actions.C, Actions.D
+C, D = Action.C, Action.D
 
 Score = Union[int, float]
 
