@@ -1,18 +1,18 @@
 from collections import defaultdict
-from functools import wraps
-import random
 import copy
 import inspect
-import types
-import numpy as np
 import itertools
+import random
 
-from axelrod.actions import Actions, flip_action, Action
+import numpy as np
+
+from axelrod.action import Action
 from .game import DefaultGame
 
+import types
 from typing import Dict, Any
 
-C, D = Actions.C, Actions.D
+C, D = Action.C, Action.D
 
 
 # Strategy classifiers
@@ -97,12 +97,14 @@ class Player(object):
     @classmethod
     def init_params(cls, *args, **kwargs):
         """
-        Return a dictionary containing the init parameters of a strategy (without 'self').
+        Return a dictionary containing the init parameters of a strategy
+        (without 'self').
         Use *args and *kwargs as value if specified
         and complete the rest with the default values.
         """
         sig = inspect.signature(cls.__init__)
-        # the 'self' parameter needs to be removed or the first *args will be assigned to it
+        # The 'self' parameter needs to be removed or the first *args will be
+        # assigned to it
         self_param = sig.parameters.get('self')
         new_params = list(sig.parameters.values())
         new_params.remove(self_param)
@@ -115,8 +117,6 @@ class Player(object):
         """Initiates an empty history and 0 score for a player."""
         self.history = []
         self.classifier = copy.deepcopy(self.classifier)
-        if self.name == "Player":
-            self.classifier['stochastic'] = False
         for dimension in self.default_classifier:
             if dimension not in self.classifier:
                 self.classifier[dimension] = self.default_classifier[dimension]
@@ -125,13 +125,13 @@ class Player(object):
         self.state_distribution = defaultdict(int)
         self.set_match_attributes()
 
-
     def __eq__(self, other):
         """
         Test if two players are equal.
         """
         if self.__repr__() != other.__repr__():
             return False
+
         for attribute in set(list(self.__dict__.keys()) +
                              list(other.__dict__.keys())):
 
@@ -149,7 +149,6 @@ class Player(object):
                 generator, original_value = itertools.tee(value)
                 other_generator, original_other_value = itertools.tee(other_value)
 
-
                 if isinstance(value, types.GeneratorType):
                     setattr(self, attribute,
                             (ele for ele in original_value))
@@ -161,21 +160,23 @@ class Player(object):
                     setattr(other, attribute,
                             itertools.cycle(original_other_value))
 
-                if not (all(next(generator) == next(other_generator)
-                        for _ in range(200))):
-                    return False
+                for _ in range(200):
+                    try:
+                        if next(generator) != next(other_generator):
+                            return False
+                    except StopIteration:
+                        break
 
             # Code for a strange edge case where each strategy points at each
             # other
             elif (value is other and other_value is self):
-                    pass
+                pass
 
             else:
                 if value != other_value:
                     return False
         return True
 
-
     def receive_match_attributes(self):
         # Overwrite this function if your strategy needs
         # to make use of match_attributes such as
@@ -207,10 +208,10 @@ class Player(object):
     def _add_noise(noise, s1, s2):
         r = random.random()
         if r < noise:
-            s1 = flip_action(s1)
+            s1 = s1.flip()
         r = random.random()
         if r < noise:
-            s2 = flip_action(s2)
+            s2 = s2.flip()
         return s1, s2
 
     def strategy(self, opponent):
