@@ -22,7 +22,7 @@ from .doubler import Doubler
 from .finite_state_machines import (
     Fortress3, Fortress4, Predator, Pun1, Raider, Ripoff, SolutionB1,
     SolutionB5, Thumper, FSMPlayer, EvolvedFSM4, EvolvedFSM16,
-    EvolvedFSM16Noise05)
+    EvolvedFSM16Noise05, TF1, TF2, TF3)
 from .forgiver import Forgiver, ForgivingTitForTat
 from .geller import Geller, GellerCooperator, GellerDefector
 from .gambler import (
@@ -51,7 +51,7 @@ from .mathematicalconstants import Golden, Pi, e
 from .memoryone import (
     MemoryOnePlayer, ALLCorALLD, FirmButFair, GTFT, SoftJoss,
     StochasticCooperator, StochasticWSLS, ZDExtort2, ZDExtort2v2, ZDExtort4,
-    ZDGen2, ZDGTFT2, ZDSet2, WinStayLoseShift, WinShiftLoseStay)
+    ZDGen2, ZDGTFT2, ZDSet2, WinStayLoseShift, WinShiftLoseStay, ReactivePlayer)
 from .memorytwo import MEM2
 from .mindcontrol import MindController, MindWarper, MindBender
 from .mindreader import MindReader, ProtectedMindReader, MirrorMindReader
@@ -76,7 +76,7 @@ from .titfortat import (
     TitForTat, TitFor2Tats, TwoTitsForTat, Bully, SneakyTitForTat,
     SuspiciousTitForTat, AntiTitForTat, HardTitForTat, HardTitFor2Tats,
     OmegaTFT, Gradual, ContriteTitForTat, SlowTitForTwoTats, AdaptiveTitForTat,
-    SpitefulTitForTat, SlowTitForTwoTats2, Alexei)
+    SpitefulTitForTat, SlowTitForTwoTats2, Alexei, EugineNier, DynamicTwoTitsForTat)
 from .verybad import VeryBad
 from .worse_and_worse import (WorseAndWorse, KnowledgeableWorseAndWorse,
                               WorseAndWorse2, WorseAndWorse3)
@@ -126,6 +126,7 @@ all_strategies = [
     DoubleResurrection,
     EasyGo,
     Eatherley,
+    EugineNier,
     EventualCycleHunter,
     EvolvedANN,
     EvolvedANN5,
@@ -237,6 +238,9 @@ all_strategies = [
     StochasticWSLS,
     SuspiciousTitForTat,
     Tester,
+    TF1,
+    TF2,
+    TF3,
     ThueMorse,
     ThueMorseInverse,
     Thumper,
@@ -262,4 +266,5 @@ all_strategies = [
     ZDGen2,
     ZDSet2,
     e,
+    DynamicTwoTitsForTat,
 ]
