@@ -1,11 +1,18 @@
-from axelrod.actions import Action, Actions
+from axelrod.action import Action
 from axelrod.player import Player
 
-C, D = Actions.C, Actions.D
+C, D = Action.C, Action.D
 
 
 class Alternator(Player):
-    """A player who alternates between cooperating and defecting."""
+    """
+    A player who alternates between cooperating and defecting.
+
+    Names
+
+    - Alternator: [Axelrod1984]_
+    - Periodic player CD: [Mittal2009]_
+    """
 
     name = 'Alternator'
     classifier = {
