@@ -4,16 +4,17 @@ Additional strategies from Axelrod's first tournament.
 
 import random
 
-from axelrod.actions import Actions, flip_action, Action
+from axelrod.action import Action
 from axelrod.player import Player
 from axelrod.random_ import random_choice
-from.memoryone import MemoryOnePlayer
 from axelrod.strategy_transformers import FinalTransformer
+from .memoryone import MemoryOnePlayer
+
 from scipy.stats import chisquare
 
 from typing import List, Dict, Tuple
 
-C, D = Actions.C, Actions.D
+C, D = Action.C, Action.D
 
 
 class Davis(Player):
@@ -123,7 +124,7 @@ class RevisedDowning(Player):
         if (c >= 0 and c >= alt):
             move = C
         elif (c >= 0 and c < alt) or (alt >= 0):
-            move = flip_action(self.history[-1])
+            move = self.history[-1].flip()
         else:
             move = D
         return move
@@ -243,8 +244,8 @@ class Joss(MemoryOnePlayer):
 
     Names:
 
-    - Joss [Axelrod1980]_
-    - Hard Joss [Stewart2012]_
+    - Joss: [Axelrod1980]_
+    - Hard Joss: [Stewart2012]_
     """
 
     name = "Joss"
@@ -490,6 +491,7 @@ class UnnamedStrategy(Player):
         r = random.uniform(3, 7) / 10
         return random_choice(r)
 
+
 @FinalTransformer((D, D), name_prefix=None)
 class SteinAndRapoport(Player):
     """
@@ -503,7 +505,7 @@ class SteinAndRapoport(Player):
 
     Names:
 
-    - SteinAndRapoport [Axelrod1980]_
+    - SteinAndRapoport: [Axelrod1980]_
     """
 
     name = 'Stein and Rapoport'
@@ -521,15 +523,15 @@ class SteinAndRapoport(Player):
         """
         Parameters
         ----------
-        alpha, float
-            The significant level of pvalue from chi-squared test
-            0.05 by default according to literature
+        alpha: float
+            The significant level of p-value from chi-squared test with
+            alpha == 0.05 by default.
         """
         super().__init__()
         self.alpha = alpha
-        self.opponent_is_random = None
+        self.opponent_is_random = False
 
-    def strategy(self , opponent: Player) -> Action:
+    def strategy(self, opponent: Player) -> Action:
         round_number = len(self.history) + 1
 
         # First 4 moves
@@ -547,9 +549,9 @@ class SteinAndRapoport(Player):
         if self.opponent_is_random:
             # Defect if opponent plays randomly
             return D
-        else: # TitForTatat if opponent plays not randomly
+        else:  # TitForTat if opponent plays not randomly
             return opponent.history[-1]
 
     def reset(self):
         super().reset()
-        self.random_opponent = None
+        self.opponent_is_random = False
