@@ -1,16 +1,20 @@
-from axelrod.actions import Actions
+from axelrod.action import Action
 from axelrod.player import Player
 from .axelrod_first import Joss
 from axelrod._strategy_utils import detect_cycle
-from axelrod.actions import Action
 
-C, D = Actions.C, Actions.D
+C, D = Action.C, Action.D
 
 
 class Calculator(Player):
     """
     Plays like (Hard) Joss for the first 20 rounds. If periodic behavior is
     detected, defect forever. Otherwise play TFT.
+
+
+    Names:
+
+    - Calculator: [Prison1998]_
     """
 
     name = "Calculator"
