@@ -1,13 +1,19 @@
-from axelrod.actions import Actions, Action
+from axelrod.action import Action
 from axelrod.player import Player
 
-C, D = Actions.C, Actions.D
+C, D = Action.C, Action.D
 
 
 class Grumpy(Player):
-    """A player that defects after a certain level of grumpiness.
+    """
+    A player that defects after a certain level of grumpiness.
     Grumpiness increases when the opponent defects and decreases
-    when the opponent co-operates."""
+    when the opponent co-operates.
+
+    Names:
+
+    - Grumpy: Original name by Jason Young
+    """
 
     name = 'Grumpy'
     classifier = {
