@@ -1,9 +1,9 @@
-from axelrod.actions import Actions, Action
+from axelrod.action import Action
 from axelrod.player import Player
 from .titfortat import TitForTat, TitFor2Tats
 from .defector import Defector
 
-C, D = Actions.C, Actions.D
+C, D = Action.C, Action.D
 
 
 class MEM2(Player):
@@ -16,7 +16,7 @@ class MEM2(Player):
 
     Names:
 
-        - MEM2 [Li2016]_
+    - MEM2: [Li2014]_
     """
 
     name = 'MEM2'
