@@ -1,7 +1,7 @@
 from collections import OrderedDict
 import random
 
-from axelrod.actions import Actions, Action
+from axelrod.action import Action, actions_to_str
 from axelrod.player import Player
 from axelrod.random_ import random_choice
 
@@ -9,7 +9,7 @@ from typing import List, Dict, Union
 
 Score = Union[int, float]
 
-C, D = Actions.C, Actions.D
+C, D = Action.C, Action.D
 
 
 class RiskyQLearner(Player):
@@ -21,7 +21,7 @@ class RiskyQLearner(Player):
 
     Names:
 
-    - Risky Q Learner: Original strategy by Geraint Palmer
+    - Risky Q Learner: Original name by Geraint Palmer
     """
 
     name = 'Risky QLearner'
@@ -92,7 +92,9 @@ class RiskyQLearner(Player):
         its previous proportion of playing C) as a hashable state
         """
         prob = '{:.1f}'.format(opponent.cooperations)
-        return ''.join(opponent.history[-self.memory_length:]) + prob
+        action_str = actions_to_str(
+            opponent.history[-self.memory_length:])
+        return action_str + prob
 
     def perform_q_learning(self, prev_state: str, state: str, action: Action, reward):
         """
@@ -133,7 +135,7 @@ class ArrogantQLearner(RiskyQLearner):
 
     Names:
 
-    - Arrogant Q Learner: Original strategy by Geraint Palmer
+    - Arrogant Q Learner: Original name by Geraint Palmer
     """
 
     name = 'Arrogant QLearner'
@@ -148,7 +150,7 @@ class HesitantQLearner(RiskyQLearner):
 
     Names:
 
-    - Hesitant Q Learner: Original strategy by Geraint Palmer
+    - Hesitant Q Learner: Original name by Geraint Palmer
     """
 
     name = 'Hesitant QLearner'
@@ -164,7 +166,7 @@ class CautiousQLearner(RiskyQLearner):
 
     Names:
 
-    - Cautious Q Learner: Original strategy by Geraint Palmer
+    - Cautious Q Learner: Original name by Geraint Palmer
     """
 
     name = 'Cautious QLearner'
