@@ -1,21 +1,22 @@
-from axelrod import Actions, Player
-from axelrod.actions import Action
+from axelrod import Player
+from axelrod.action import Action
+
+C, D = Action.C, Action.D
 
-C, D = Actions.C, Actions.D
 
 class ShortMem(Player):
     """
     A player starts by always cooperating for the first 10 moves.
-    
+
     From the tenth round on, the player analyzes the last ten actions, and
     compare the number of defects and cooperates of the opponent, based in
     percentage. If cooperation occurs 30% more than defection, it will
     cooperate.
     If defection occurs 30% more than cooperation, the program will defect.
     Otherwise, the program follows the TitForTat algorithm.
-    
+
     Names:
-    
+
     - ShortMem: [Andre2013]_
     """
 
@@ -32,18 +33,16 @@ class ShortMem(Player):
 
     @staticmethod
     def strategy(opponent: Player) -> Action:
-        
         if len(opponent.history) <= 10:
             return C
-        
+
         array = opponent.history[-10:]
-        C_counts = array.count('C')
-        D_counts = array.count('D')
-            
+        C_counts = array.count(C)
+        D_counts = array.count(D)
+
         if C_counts - D_counts >= 3:
             return C
         elif D_counts - C_counts >= 3:
             return D
         else:
             return opponent.history[-1]
-        
