@@ -1,8 +1,10 @@
-from axelrod.actions import Actions, Action
+from axelrod.action import Action, actions_to_str
 from axelrod.player import Player
-from axelrod.strategy_transformers import TrackHistoryTransformer, FinalTransformer
+from axelrod.random_ import random_choice
+from axelrod.strategy_transformers import (
+    TrackHistoryTransformer, FinalTransformer)
 
-C, D = Actions.C, Actions.D
+C, D = Action.C, Action.D
 
 
 class TitForTat(Player):
@@ -93,6 +95,43 @@ class TwoTitsForTat(Player):
         return D if D in opponent.history[-2:] else C
 
 
+class DynamicTwoTitsForTat(Player):
+    """
+    A player starts by cooperating and then punishes its opponent's
+    defections with defections, but with a dynamic bias towards cooperating
+    based on the opponent's ratio of cooperations to total moves
+    (so their current probability of cooperating regardless of the
+    opponent's move (aka: forgiveness)).
+
+    Names:
+
+     - Dynamic Two Tits For Tat: Original name by Grant Garrett-Grossman.
+    """
+
+    name = 'Dynamic Two Tits For Tat'
+    classifier = {
+        'memory_depth': 2,  # Long memory, memory-2
+        'stochastic': True,
+        'makes_use_of': set(),
+        'long_run_time': False,
+        'inspects_source': False,
+        'manipulates_source': False,
+        'manipulates_state': False
+    }
+
+    @staticmethod
+    def strategy(opponent):
+        # First move
+        if not opponent.history:
+            # Make sure we cooporate first turn
+            return C
+        if D in opponent.history[-2:]:
+            # Probability of cooperating regardless
+            return random_choice(opponent.cooperations / len(opponent.history))
+        else:
+            return C
+
+
 class Bully(Player):
     """A player that behaves opposite to Tit For Tat, including first move.
 
@@ -127,7 +166,7 @@ class SneakyTitForTat(Player):
 
     Names:
 
-    - Sneaky Tit For Tat: Reference Required
+    - Sneaky Tit For Tat: Original name by Karol Langner
     """
 
     name = "Sneaky Tit For Tat"
@@ -143,11 +182,11 @@ class SneakyTitForTat(Player):
 
     def strategy(self, opponent: Player) -> Action:
         if len(self.history) < 2:
-            return "C"
+            return C
         if D not in opponent.history:
             return D
         if opponent.history[-1] == D and self.history[-2] == D:
-            return "C"
+            return C
         return opponent.history[-1]
 
 
@@ -156,7 +195,7 @@ class SuspiciousTitForTat(Player):
 
     Names:
 
-    - Suspicious Tit For Tat: [Hilde2013]_
+    - Suspicious Tit For Tat: [Hilbe2013]_
     - Mistrust: [Beaufils1997]_
     """
 
@@ -182,7 +221,7 @@ class AntiTitForTat(Player):
 
     Names:
 
-    - Anti Tit For Tat: [Hilde2013]_
+    - Anti Tit For Tat: [Hilbe2013]_
     """
 
     name = 'Anti Tit For Tat'
@@ -206,7 +245,7 @@ class HardTitForTat(Player):
 
     Names:
 
-    - Hard Tit For Tat: Reference Required
+    - Hard Tit For Tat: [PD2017]_
     """
 
     name = 'Hard Tit For Tat'
@@ -238,7 +277,7 @@ class HardTitFor2Tats(Player):
 
     Names:
 
-    - Hard Tit For Two Tats: Reference Required
+    - Hard Tit For Two Tats: [Stewart2012]_
     """
 
     name = "Hard Tit For 2 Tats"
@@ -258,7 +297,7 @@ class HardTitFor2Tats(Player):
         if not opponent.history:
             return C
         # Defects if two consecutive D in the opponent's last three moves
-        history_string = "".join(opponent.history[-3:])
+        history_string = actions_to_str(opponent.history[-3:])
         if 'DD' in history_string:
             return D
         # Otherwise cooperates
@@ -459,6 +498,9 @@ class SlowTitForTwoTats(Player):
     A player plays C twice, then if the opponent plays the same move twice,
     plays that move.
 
+    Names:
+
+    - Slow tit for two tats: Original name by Ranjini Das
     """
 
     name = 'Slow Tit For Two Tats'
@@ -565,7 +607,7 @@ class SpitefulTitForTat(Player):
 
     Names:
 
-    - Spiteful Tit For Tat [Prison1998]_
+    - Spiteful Tit For Tat: [Prison1998]_
     """
 
     name = 'Spiteful Tit For Tat'
@@ -611,7 +653,7 @@ class SlowTitForTwoTats2(Player):
 
     Names:
 
-    - Slow Tit For Tat [Prison1998]_
+    - Slow Tit For Tat: [Prison1998]_
     """
 
     name = 'Slow Tit For Two Tats 2'
@@ -642,10 +684,10 @@ class SlowTitForTwoTats2(Player):
 class Alexei(Player):
     """
     Plays similar to Tit-for-Tat, but always defect on last turn.
-    
+
     Names:
 
-    - Alexei's Strategy: [LessWrong2011]_    
+    - Alexei: [LessWrong2011]_
     """
 
     name = 'Alexei'
@@ -665,3 +707,43 @@ class Alexei(Player):
         if opponent.history[-1] == D:
             return D
         return C
+
+@FinalTransformer((D,), name_prefix=None)
+class EugineNier(Player):
+    """
+    Plays similar to Tit-for-Tat, but with two conditions:
+    1) Always Defect on Last Move
+    2) If other player defects five times, switch to all defects.
+
+    Names:
+
+    - Eugine Nier: [LessWrong2011]_
+    """
+
+    name = 'EugineNier'
+    classifier = {
+        'memory_depth': float('inf'),
+        'stochastic': False,
+        'makes_use_of': {'length'},
+        'long_run_time': False,
+        'inspects_source': False,
+        'manipulates_source': False,
+        'manipulates_state': False
+    }
+
+    def __init__(self):
+        super().__init__()
+        self.is_defector = False
+
+    def strategy(self, opponent: Player) -> Action:
+        if not self.history:
+            return C
+        if not (self.is_defector) and opponent.defections >= 5:
+            self.is_defector = True
+        if self.is_defector:
+            return D
+        return opponent.history[-1]
+
+    def reset(self):
+        super().reset()
+        self.is_defector = False
