@@ -10,11 +10,11 @@ import copy
 import inspect
 import random
 from numpy.random import choice
-from .actions import Actions, flip_action
+from .action import Action
 from .random_ import random_choice
 
 
-C, D = Actions.C, Actions.D
+C, D = Action.C, Action.D
 
 # Note: After a transformation is applied, the player's history is overwritten
 # with the modified history just like in the noisy tournament case. This can
@@ -130,11 +130,13 @@ def StrategyTransformerFactory(strategy_wrapper, name_prefix=None,
                 prefix = ': '
                 for arg in args:
                     try:
-                        arg = [player.name for player in arg]
-                    except TypeError:
-                        pass
+                        # Action has .name but should not be made into a list
+                        if not any(isinstance(el, Action) for el in arg):
+                            arg = [player.name for player in arg]
                     except AttributeError:
                         pass
+                    except TypeError:
+                        pass
                     name = ''.join([name, prefix, str(arg)])
                     prefix = ', '
                 return name
@@ -198,8 +200,8 @@ IdentityTransformer = StrategyTransformerFactory(generic_strategy_wrapper)
 
 
 def flip_wrapper(player, opponent, action):
-    """Applies flip_action at the class level."""
-    return flip_action(action)
+    """Flips the player's original actions."""
+    return action.flip()
 
 
 FlipTransformer = StrategyTransformerFactory(
@@ -231,17 +233,17 @@ def dual_wrapper(player, opponent, proposed_action):
 
     action = player.original_player.strategy(opponent)
     player.original_player.history.append(action)
-    return flip_action(action)
+    return action.flip()
 
 
 DualTransformer = StrategyTransformerFactory(dual_wrapper, name_prefix="Dual")
 
 
 def noisy_wrapper(player, opponent, action, noise=0.05):
-    """Applies flip_action at the class level."""
+    """Flips the player's actions with probability: `noise`."""
     r = random.random()
     if r < noise:
-        return flip_action(action)
+        return action.flip()
     return action
 
 def noisy_reclassifier(original_classifier, noise):
