@@ -7,53 +7,67 @@ import warnings
 
 import tqdm
 
-from axelrod import on_windows
+from axelrod import on_windows, DEFAULT_TURNS
 from axelrod.player import Player
+from axelrod.action import actions_to_str
 from .game import Game
 from .match import Match
-from .match_generator import RoundRobinMatches, ProbEndRoundRobinMatches, SpatialMatches, ProbEndSpatialMatches, MatchGenerator
+from .match_generator import MatchGenerator
 from .result_set import ResultSetFromFile, ResultSet
 
-from typing import List
+from typing import List, Tuple
+
 
 class Tournament(object):
 
-    def __init__(self, players: List[Player], match_generator: MatchGenerator=RoundRobinMatches,
-                 name: str='axelrod', game: Game=None, turns: int=200, repetitions: int=10,
-                 noise: float=0, with_morality: bool=True) -> None:
+    def __init__(self, players: List[Player],
+                 name: str = 'axelrod', game: Game = None, turns: int = None,
+                 prob_end: float = None, repetitions: int = 10,
+                 noise: float = 0, edges: List[Tuple] = None) -> None:
         """
         Parameters
         ----------
         players : list
             A list of axelrod.Player objects
-        match_generator : class
-            A class that must be descended from axelrod.MatchGenerator
         name : string
             A name for the tournament
         game : axelrod.Game
             The game object used to score the tournament
         turns : integer
             The number of turns per match
+        prob_end : float
+            The probability of a given turn ending a match
         repetitions : integer
             The number of times the round robin should be repeated
         noise : float
             The probability that a player's intended action should be flipped
-        with_morality : boolean
-            Whether morality metrics should be calculated
+        prob_end : float
+            The probability of a given turn ending a match
+        edges : list
+            A list of edges between players
         """
         if game is None:
             self.game = Game()
         else:
             self.game = game
         self.name = name
-        self.turns = turns
         self.noise = noise
         self.num_interactions = 0
         self.players = players
         self.repetitions = repetitions
-        self.match_generator = match_generator(
-            players, turns, self.game, self.repetitions, self.noise)
-        self._with_morality = with_morality
+        self.edges = edges
+
+        if turns is None and prob_end is None:
+            turns = DEFAULT_TURNS
+
+        self.turns = turns
+        self.prob_end = prob_end
+        self.match_generator = MatchGenerator(players=players, turns=turns,
+                                              game=self.game,
+                                              repetitions=self.repetitions,
+                                              prob_end=prob_end,
+                                              noise=self.noise,
+                                              edges=edges)
         self._logger = logging.getLogger(__name__)
 
     def setup_output(self, filename=None, in_memory=False):
@@ -72,9 +86,10 @@ class Tournament(object):
             # Save filename for loading ResultSet later
             self.filename = filename
 
-    def play(self, build_results: bool=True, filename: str=None,
-             processes: int=None, progress_bar: bool=True,
-             keep_interactions: bool=False, in_memory: bool=False) -> ResultSetFromFile:
+    def play(self, build_results: bool = True, filename: str = None,
+             processes: int = None, progress_bar: bool = True,
+             keep_interactions: bool = False, in_memory: bool = False
+             ) -> ResultSetFromFile:
         """
         Plays the tournament and passes the results to the ResultSet class
 
@@ -132,8 +147,9 @@ class Tournament(object):
         elif not in_memory:
             self.outputfile.close()
 
-    def _build_result_set(self, progress_bar: bool=True, keep_interactions: bool=False,
-                          in_memory: bool=False):
+    def _build_result_set(self, progress_bar: bool = True,
+                          keep_interactions: bool = False,
+                          in_memory: bool = False):
         """
         Build the result set (used by the play method)
 
@@ -160,7 +176,7 @@ class Tournament(object):
                 game=self.game)
         return result_set
 
-    def _run_serial(self, progress_bar: bool=False) -> bool:
+    def _run_serial(self, progress_bar: bool = False) -> bool:
         """
         Run all matches in serial
 
@@ -195,8 +211,8 @@ class Tournament(object):
                 row = list(index_pair)
                 row.append(str(self.players[index_pair[0]]))
                 row.append(str(self.players[index_pair[1]]))
-                history1 = "".join([i[0] for i in interaction])
-                history2 = "".join([i[1] for i in interaction])
+                history1 = actions_to_str([i[0] for i in interaction])
+                history2 = actions_to_str([i[1] for i in interaction])
                 row.append(history1)
                 row.append(history2)
                 self.writer.writerow(row)
@@ -212,7 +228,8 @@ class Tournament(object):
                     self.interactions_dict[index_pair] = [interaction]
                 self.num_interactions += 1
 
-    def _run_parallel(self, processes: int=2, progress_bar: bool=False) -> bool:
+    def _run_parallel(self, processes: int=2, progress_bar: bool = False
+                      ) -> bool:
         """
         Run all matches in parallel
 
@@ -238,7 +255,7 @@ class Tournament(object):
 
         return True
 
-    def _n_workers(self, processes: int=2) -> int:
+    def _n_workers(self, processes: int = 2) -> int:
         """
         Determines the number of parallel processes to use.
 
@@ -252,7 +269,8 @@ class Tournament(object):
             n_workers = cpu_count()
         return n_workers
 
-    def _start_workers(self, workers: int, work_queue: Queue, done_queue: Queue) -> bool:
+    def _start_workers(self, workers: int, work_queue: Queue,
+                       done_queue: Queue) -> bool:
         """
         Initiates the sub-processes to carry out parallel processing.
 
@@ -272,7 +290,8 @@ class Tournament(object):
             process.start()
         return True
 
-    def _process_done_queue(self, workers: int, done_queue: Queue, progress_bar: bool=False):
+    def _process_done_queue(self, workers: int, done_queue: Queue,
+                            progress_bar: bool = False):
         """
         Retrieves the matches from the parallel sub-processes
 
@@ -329,125 +348,16 @@ class Tournament(object):
         interactions : dictionary
             Mapping player index pairs to results of matches:
 
-                (0, 1) -> [('C', 'D'), ('D', 'C'),...]
+                (0, 1) -> [(C, D), (D, C),...]
         """
         interactions = defaultdict(list)
         index_pair, match_params, repetitions = chunk
         p1_index, p2_index = index_pair
         player1 = self.players[p1_index].clone()
         player2 = self.players[p2_index].clone()
-        players = (player1, player2)
-        params = [players]
-        params.extend(match_params)
-        match = Match(*params)
+        match_params["players"] = (player1, player2)
+        match = Match(**match_params)
         for _ in range(repetitions):
             match.play()
             interactions[index_pair].append(match.result)
         return interactions
-
-
-class ProbEndTournament(Tournament):
-    """
-    A tournament in which the player don't know the length of a given match. The
-    length of a match is equivalent to randomly sampling after each round
-    whether or not to continue.
-    """
-
-    def __init__(self, players, name='axelrod', game=None, prob_end=.5,
-                 repetitions=10, noise=0, with_morality=True):
-        """
-        Parameters
-        ----------
-        players : list
-            A list of axelrod.Player objects
-        name : string
-            A name for the tournament
-        game : axelrod.Game
-            The game object used to score the tournament
-        prob_end : a float
-            The probability of a given match ending
-        repetitions : integer
-            The number of times the round robin should be repeated
-        noise : float
-            The probability that a player's intended action should be flipped
-        with_morality : boolean
-            Whether morality metrics should be calculated
-        """
-        super().__init__(
-            players, name=name, game=game, turns=float("inf"),
-            repetitions=repetitions, noise=noise, with_morality=with_morality)
-
-        self.prob_end = prob_end
-        self.match_generator = ProbEndRoundRobinMatches(
-            players, prob_end, self.game, repetitions)
-
-
-class SpatialTournament(Tournament):
-    """
-    A tournament in which the players are allocated in a graph as nodes
-    and they players only play the others that are connected to with an edge.
-    """
-    def __init__(self, players: List[Player], edges, name: str='axelrod', game: Game=None, turns: int=200,
-                 repetitions: int=10, noise: float=0, with_morality: bool=True) -> None:
-        """
-        Parameters
-        ----------
-        players : list
-            A list of axelrod.Player objects
-        name : string
-            A name for the tournament
-        game : axelrod.Game
-            The game object used to score the tournament
-        edges : list
-            A list of tuples containing the existing edges
-        repetitions : integer
-            The number of times the round robin should be repeated
-        noise : float
-            The probability that a player's intended action should be flipped
-        with_morality : boolean
-            Whether morality metrics should be calculated
-        """
-        super().__init__(
-            players, name=name, game=game, turns=turns,
-            repetitions=repetitions, noise=noise, with_morality=with_morality)
-
-        self.edges = edges
-        self.match_generator = SpatialMatches(
-            players, turns, self.game, repetitions, edges, noise)
-
-
-class ProbEndSpatialTournament(ProbEndTournament):
-    """
-    A tournament in which the players are allocated in a graph as nodes
-    and they players only play the others that are connected to with an edge.
-    Players do not know the length of a given match (it is randomly sampled).
-    """
-    def __init__(self, players: List[Player], edges, name: str='axelrod', game: Game=None, prob_end: float=.5,
-                 repetitions: int=10, noise: float=0, with_morality: bool=True) -> None:
-        """
-        Parameters
-        ----------
-        players : list
-            A list of axelrod.Player objects
-        name : string
-            A name for the tournament
-        game : axelrod.Game
-            The game object used to score the tournament
-        prob_end : a float
-            The probability of a given match ending
-        edges : list
-            A list of tuples containing the existing edges
-        repetitions : integer
-            The number of times the round robin should be repeated
-        noise : float
-            The probability that a player's intended action should be flipped
-        with_morality : boolean
-            Whether morality metrics should be calculated
-        """
-        super().__init__(
-            players, name=name, game=game, prob_end=prob_end,
-            repetitions=repetitions, noise=noise, with_morality=with_morality)
-
-        self.edges = edges
-        self.match_generator = ProbEndSpatialMatches(
-            players, prob_end, self.game, repetitions, noise, edges)
